% This function derives the contact matrix from the agents' and individuals' contact traces
%
% Input:
% contTrace is a cell containing M matrices where each matrix corresponds to the
% traces of one agent.  Each matrix has two columns where the first column
% is the ID of the individual contacted by the agent and the second column
% is the time of contact.
% NOTE: the IDs of discovered individuals in contTrace must be numbered
% from 1 to S.
% M is the number of agents and S is the number of discovered individuals.
%
% Output:
% contMat is an SxM matrix where element ij is equal to the number of times
% that agent j contacts individual i, for 1<=i<=S and 1<=j<=M.

function[contMat] = contMatCalc(contTrace, M, S)

% reformating the agents' traces
trace = [];
for agentIter = 1:M
    % iteration over each agent
    agentTrace = contTrace{agentIter, 1};
    trace = [trace; [agentIter * ones(size(agentTrace, 1), 1) agentTrace(:, 1)]];
end

% calsulating the contact Matrix
contMat = sparse(trace(:, 2), trace(:, 1), 1, S, M);
contMat = full(contMat);